aboutsummaryrefslogtreecommitdiff
path: root/include/libbb.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libbb.h')
-rw-r--r--include/libbb.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/libbb.h b/include/libbb.h
index 44bd6e09d..dd23c704d 100644
--- a/include/libbb.h
+++ b/include/libbb.h
@@ -317,13 +317,13 @@ int xconnect_stream(const len_and_sockaddr *lsa);
* Currently will return IPv4 or IPv6 sockaddrs only
* (depending on host), but in theory nothing prevents e.g.
* UNIX socket address being returned, IPX sockaddr etc... */
-len_and_sockaddr* host2sockaddr(const char *host, int port);
+len_and_sockaddr* xhost2sockaddr(const char *host, int port);
#if ENABLE_FEATURE_IPV6
/* Same, useful if you want to force family (e.g. IPv6) */
-len_and_sockaddr* host_and_af2sockaddr(const char *host, int port, sa_family_t af);
+len_and_sockaddr* xhost_and_af2sockaddr(const char *host, int port, sa_family_t af);
#else
/* [we evaluate af: think about "host_and_af2sockaddr(..., af++)"] */
#define host_and_af2sockaddr(host, port, af) ((void)(af), host2sockaddr((host), (port)))
#endif
/* Assign sin[6]_port member if the socket is of corresponding type,
* otherwise no-op. Useful for ftp.
@@ -317,13 +317,13 @@ int xconnect_stream(const len_and_sockaddr *lsa);
#else
-/* [we evaluate af: think about "host_and_af2sockaddr(..., af++)"] */
-#define host_and_af2sockaddr(host, port, af) ((void)(af), host2sockaddr((host), (port)))
+/* [we evaluate af: think about "xhost_and_af2sockaddr(..., af++)"] */
+#define xhost_and_af2sockaddr(host, port, af) ((void)(af), xhost2sockaddr((host), (port)))
#endif
/* Assign sin[6]_port member if the socket is of corresponding type,